@@ -1,9 +1,9 @@
-use std::collections::BTreeMap;
-use crate::clarity::costs::{ExecutionCost, LimitedCostTracker};
 use crate::clarity::analysis::ContractAnalysis;
 use crate::clarity::ast::ContractAST;
+use crate::clarity::costs::{ExecutionCost, LimitedCostTracker};
 use crate::clarity::coverage::TestCoverageReport;
 use serde_json::Value;
+use std::collections::BTreeMap;
 
 pub mod interpreter;
 pub mod session;
@@ -15,7 +15,13 @@ pub use settings::SessionSettings;
 
 #[derive(Default)]
 pub struct ExecutionResult {
-    pub contract: Option<(String, String, BTreeMap<String, Vec<String>>, ContractAST, ContractAnalysis)>,
+    pub contract: Option<(
+        String,
+        String,
+        BTreeMap<String, Vec<String>>,
+        ContractAST,
+        ContractAnalysis,
+    )>,
     pub result: Option<String>,
     pub events: Vec<Value>,
     pub cost: Option<CostSynthesis>,
@@ -31,7 +37,6 @@ pub struct CostSynthesis {
 }
 
 impl CostSynthesis {
-
     pub fn from_cost_tracker(cost_tracker: &LimitedCostTracker) -> CostSynthesis {
         CostSynthesis {
             total: cost_tracker.get_total(),
@@ -40,4 +45,4 @@ impl CostSynthesis {
             memory_limit: cost_tracker.memory_limit,
         }
     }
-}
\ No newline at end of file
+}
